@@ -150,6 +150,16 @@ def get_version_info():
     return _VERSIONS.copy()
 
 
+def convert_value(value, from_convert_factor, to_convert_factor):
+    value_in_base_unit = (
+        value * from_convert_factor.get("factor")
+    ) + from_convert_factor.get("offset", 0)
+
+    return float(
+        value_in_base_unit - to_convert_factor.get("offset", 0)
+    ) / to_convert_factor.get("factor")
+
+
 def get_data(url, headers, params=None, logger=None):
     """General 'make api request' function.
 
@@ -338,6 +348,7 @@ def get_data_call_params(**selection):
     start_date : string, optional
     end_date : string, optional
     show_revisions : boolean, optional
+    show_available_date : boolean, optional
     insert_null : boolean, optional
     show_metadata : boolean, optional
     at_time : string, optional
@@ -352,7 +363,7 @@ def get_data_call_params(**selection):
     for key, value in list(selection.items()):
         if key == 'show_metadata':
             params[groclient.utils.str_snake_to_camel('show_meta_data')] = value
-        if key in ('start_date', 'end_date', 'show_revisions', 'insert_null', 'at_time'):
+        if key in ('start_date', 'end_date', 'show_revisions', 'show_available_date', 'insert_null', 'at_time'):
             params[groclient.utils.str_snake_to_camel(key)] = value
     params['responseType'] = 'list_of_series'
     return params
@@ -426,9 +437,13 @@ def rank_series_by_source(access_token, api_host, selections_list):
             for idx, type_id in enumerate(DATA_SERIES_UNIQUE_TYPES_ID)
             if type_id != 'source_id' and series_key.split('.')[idx] != 'null'
         }
-        source_ids = get_source_ranking(access_token,
-                                        api_host,
-                                        series_without_source)
+        try:
+            source_ids = get_source_ranking(access_token,
+                                            api_host,
+                                            series_without_source)
+        # Catch "no content" response from get_source_ranking()
+        except ValueError:
+            continue  # empty response
 
         for source_id in source_ids:
             if source_id in series_by_source_id:
@@ -449,7 +464,7 @@ def get_available_timefrequency(access_token, api_host, **series):
             for tf in response.json()]
 
 
-def list_of_series_to_single_series(series_list, add_belongs_to=False, include_historical=True):
+def list_of_series_to_single_series(series_list, add_belongs_to=False, include_historical=True, include_available_date=False):
     """Convert list_of_series format from API back into the familiar single_series output format."""
     if not isinstance(series_list, list):
         # If the output is an error or None or something else that's not a list, just propagate
@@ -474,7 +489,7 @@ def list_of_series_to_single_series(series_list, add_belongs_to=False, include_h
                 'end_date': point[1],
                 'value': point[2],
                 'unit_id': point[4] if len(point) > 4 else series['series'].get('unitId', None),
-                'metadata': point[5] if len(point) > 5 else {},
+                'metadata': point[5] if len(point) > 5 and point[5] is not None else {},
                 # input_unit_id and input_unit_scale are deprecated but provided for backwards
                 # compatibility. unit_id should be used instead.
                 'input_unit_id': point[4] if len(point) > 4 else series['series'].get('unitId', None),
@@ -489,6 +504,13 @@ def list_of_series_to_single_series(series_list, add_belongs_to=False, include_h
                 'frequency_id': series['series'].get('frequencyId', None)
                 # 'source_id': series['series'].get('sourceId', None), TODO: add source to output
             }
+            if include_available_date:
+                # If a point does not have available_date, use None
+                formatted_point['available_date'] = point[6] if len(point) > 6 else None
+
+            if formatted_point['metadata'].get('confInterval') is not None:
+                formatted_point['metadata']['conf_interval'] = formatted_point['metadata'].pop('confInterval')
+
             if add_belongs_to:
                 # belongs_to is consistent with the series the user requested. So if an
                 # expansion happened on the server side, the user can reconstruct what
@@ -504,7 +526,8 @@ def get_data_points(access_token, api_host, **selection):
     params = get_data_call_params(**selection)
     resp = get_data(url, headers, params)
     include_historical = selection.get('include_historical', True)
-    return list_of_series_to_single_series(resp.json(), False, include_historical)
+    include_available_date = selection.get('show_available_date', False)
+    return list_of_series_to_single_series(resp.json(), False, include_historical, include_available_date)
 
 
 @memoize(maxsize=None)
@@ -581,6 +604,26 @@ def get_geojson(access_token, api_host, region_id, zoom_level):
         return json.loads(region['geojson'])
 
 
+def get_descendant(access_token, api_host, entity_type, entity_id, distance=None,
+                   include_details=True):
+    url = '/'.join(['https:', '', api_host, 'v2/{}/contains'.format(entity_type)])
+    headers = {'authorization': 'Bearer ' + access_token}
+    params = {'ids': [entity_id]}
+    if distance:
+        params['distance'] = distance
+    else:
+        params['distance'] = -1
+
+    resp = get_data(url, headers, params)
+    descendant_entity_ids = resp.json()['data'][str(entity_id)]
+
+    if include_details:
+        entity_details = lookup(access_token, api_host, entity_type, descendant_entity_ids)
+        return [entity_details[str(child_entity_id)] for child_entity_id in descendant_entity_ids]
+
+    return [{'id': descendant_entity_id} for descendant_entity_id in descendant_entity_ids]
+
+
 def get_descendant_regions(access_token, api_host, region_id,
                            descendant_level=None, include_historical=True, include_details=True):
     url = '/'.join(['https:', '', api_host, 'v2/regions/contains'])
