@@ -185,7 +185,8 @@ def test_list_of_series_to_single_series():
         'data': [
             ['2001-01-01', '2001-12-31', 123],
             ['2002-01-01', '2002-12-31', 123, '2012-01-01'],
-            ['2003-01-01', '2003-12-31', 123, None, 15, {'confInterval': 2}]
+            ['2003-01-01', '2003-12-31', 123, None, 15, {'confInterval': 2}],
+            ['2004-01-01', '2004-12-31', 123, None, 15, None, '2013-01-01']
         ]
     }], add_belongs_to=True) == [
         {'start_date': '2001-01-01',
@@ -230,6 +231,20 @@ def test_list_of_series_to_single_series():
          'partner_region_id': 0,
          'frequency_id': None,
          'belongs_to': {'item_id': 22}},
+        {'start_date': '2004-01-01',
+         'end_date': '2004-12-31',
+         'value': 123,
+         'unit_id': 15,
+         'metadata': {},
+         'input_unit_id': 15,
+         'input_unit_scale': 1,
+         'reporting_date': None,
+         'metric_id': 1,
+         'item_id': 2,
+         'region_id': 3,
+         'partner_region_id': 0,
+         'frequency_id': None,
+         'belongs_to': {'item_id': 22}},
     ]
 
     # test the add_belongs_to kwarg:
@@ -254,6 +269,82 @@ def test_list_of_series_to_single_series():
         'data': [['2001-01-01', '2001-12-31', 123]]
     }], include_historical=True)) == 1
 
+    # test the include_available_date kwarg:
+    assert lib.list_of_series_to_single_series([{
+        'series': {
+            'metricId': 1,
+            'itemId': 2,
+            'regionId': 3,
+            'unitId': 4,
+            'inputUnitId': 5,
+            'belongsTo': {'itemId': 22},
+            'metadata': {'includesHistoricalRegion': True}
+        },
+        'data': [['2004-01-01', '2004-12-31', 123, None, 15]]
+    }], include_available_date=False) == [
+        {'start_date': '2004-01-01',
+         'end_date': '2004-12-31',
+         'value': 123,
+         'unit_id': 15,
+         'metadata': {},
+         'input_unit_id': 15,
+         'input_unit_scale': 1,
+         'reporting_date': None,
+         'metric_id': 1,
+         'item_id': 2,
+         'region_id': 3,
+         'partner_region_id': 0,
+         'frequency_id': None
+        }
+    ]
+
+    assert lib.list_of_series_to_single_series([{
+        'series': {
+            'metricId': 1,
+            'itemId': 2,
+            'regionId': 3,
+            'unitId': 4,
+            'inputUnitId': 5,
+            'belongsTo': {'itemId': 22},
+            'metadata': {'includesHistoricalRegion': True}
+        },
+        'data': [
+            ['2003-01-01', '2003-12-31', 123, None, 15],
+            ['2004-01-01', '2004-12-31', 123, None, 15, None, '2013-01-01']
+        ]
+    }], include_available_date=True) == [
+        {'start_date': '2003-01-01',
+         'end_date': '2003-12-31',
+         'value': 123,
+         'unit_id': 15,
+         'metadata': {},
+         'input_unit_id': 15,
+         'input_unit_scale': 1,
+         'reporting_date': None,
+         'available_date': None,
+         'metric_id': 1,
+         'item_id': 2,
+         'region_id': 3,
+         'partner_region_id': 0,
+         'frequency_id': None
+        },
+        {'start_date': '2004-01-01',
+         'end_date': '2004-12-31',
+         'value': 123,
+         'unit_id': 15,
+         'metadata': {},
+         'input_unit_id': 15,
+         'input_unit_scale': 1,
+         'reporting_date': None,
+         'available_date': '2013-01-01',
+         'metric_id': 1,
+         'item_id': 2,
+         'region_id': 3,
+         'partner_region_id': 0,
+         'frequency_id': None
+        }
+    ]
+
     # test invalid input propagation
     assert lib.list_of_series_to_single_series('test input') == 'test input'
 
